# Autogenerated by get_module_idx.py

d = { 'settings': {'lib_path': 'nbdev_sphinx'},
  'syms': { 'docutils.parsers': {'docutils.parsers.rst': 'https://www.sphinx-doc.org/en/stable/extdev/markupapi.html#module-docutils.parsers.rst'},
            'docutils.parsers.rst': { 'docutils.parsers.rst.Directive': 'https://www.sphinx-doc.org/en/stable/extdev/markupapi.html#docutils.parsers.rst.Directive',
                                      'docutils.parsers.rst.Directive.run': 'https://www.sphinx-doc.org/en/stable/extdev/markupapi.html#docutils.parsers.rst.Directive.run'},
            'sphinx': { 'sphinx.addnodes': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#module-sphinx.addnodes',
                        'sphinx.application': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#module-sphinx.application',
                        'sphinx.builders': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders',
                        'sphinx.directives': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#module-sphinx.directives',
                        'sphinx.domains': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#module-sphinx.domains',
                        'sphinx.environment': 'https://www.sphinx-doc.org/en/stable/extdev/envapi.html#module-sphinx.environment',
                        'sphinx.errors': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#module-sphinx.errors',
                        'sphinx.parsers': 'https://www.sphinx-doc.org/en/stable/extdev/parserapi.html#module-sphinx.parsers'},
            'sphinx.addnodes': { 'sphinx.addnodes.compact_paragraph': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.compact_paragraph',
                                 'sphinx.addnodes.desc': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc',
                                 'sphinx.addnodes.desc_addname': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_addname',
                                 'sphinx.addnodes.desc_annotation': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_annotation',
                                 'sphinx.addnodes.desc_content': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_content',
                                 'sphinx.addnodes.desc_inline': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_inline',
                                 'sphinx.addnodes.desc_name': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_name',
                                 'sphinx.addnodes.desc_optional': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_optional',
                                 'sphinx.addnodes.desc_parameter': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_parameter',
                                 'sphinx.addnodes.desc_parameterlist': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_parameterlist',
                                 'sphinx.addnodes.desc_returns': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_returns',
                                 'sphinx.addnodes.desc_signature': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_signature',
                                 'sphinx.addnodes.desc_signature_line': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_signature_line',
                                 'sphinx.addnodes.desc_type': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.desc_type',
                                 'sphinx.addnodes.download_reference': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.download_reference',
                                 'sphinx.addnodes.glossary': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.glossary',
                                 'sphinx.addnodes.highlightlang': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.highlightlang',
                                 'sphinx.addnodes.index': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.index',
                                 'sphinx.addnodes.literal_emphasis': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.literal_emphasis',
                                 'sphinx.addnodes.only': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.only',
                                 'sphinx.addnodes.pending_xref': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.pending_xref',
                                 'sphinx.addnodes.pending_xref_condition': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.pending_xref_condition',
                                 'sphinx.addnodes.production': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.production',
                                 'sphinx.addnodes.productionlist': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.productionlist',
                                 'sphinx.addnodes.seealso': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.seealso',
                                 'sphinx.addnodes.start_of_file': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.start_of_file',
                                 'sphinx.addnodes.toctree': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.toctree',
                                 'sphinx.addnodes.versionmodified': 'https://www.sphinx-doc.org/en/stable/extdev/nodes.html#sphinx.addnodes.versionmodified'},
            'sphinx.application': { 'sphinx.application.Sphinx': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx',
                                    'sphinx.application.Sphinx.add_autodoc_attrgetter': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_autodoc_attrgetter',
                                    'sphinx.application.Sphinx.add_autodocumenter': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_autodocumenter',
                                    'sphinx.application.Sphinx.add_builder': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_builder',
                                    'sphinx.application.Sphinx.add_config_value': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_config_value',
                                    'sphinx.application.Sphinx.add_crossref_type': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_crossref_type',
                                    'sphinx.application.Sphinx.add_css_file': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_css_file',
                                    'sphinx.application.Sphinx.add_directive': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_directive',
                                    'sphinx.application.Sphinx.add_directive_to_domain': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_directive_to_domain',
                                    'sphinx.application.Sphinx.add_domain': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_domain',
                                    'sphinx.application.Sphinx.add_enumerable_node': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_enumerable_node',
                                    'sphinx.application.Sphinx.add_env_collector': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_env_collector',
                                    'sphinx.application.Sphinx.add_event': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_event',
                                    'sphinx.application.Sphinx.add_generic_role': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_generic_role',
                                    'sphinx.application.Sphinx.add_html_math_renderer': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_html_math_renderer',
                                    'sphinx.application.Sphinx.add_html_theme': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_html_theme',
                                    'sphinx.application.Sphinx.add_index_to_domain': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_index_to_domain',
                                    'sphinx.application.Sphinx.add_js_file': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_js_file',
                                    'sphinx.application.Sphinx.add_latex_package': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_latex_package',
                                    'sphinx.application.Sphinx.add_lexer': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_lexer',
                                    'sphinx.application.Sphinx.add_message_catalog': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_message_catalog',
                                    'sphinx.application.Sphinx.add_node': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_node',
                                    'sphinx.application.Sphinx.add_object_type': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_object_type',
                                    'sphinx.application.Sphinx.add_post_transform': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_post_transform',
                                    'sphinx.application.Sphinx.add_role': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_role',
                                    'sphinx.application.Sphinx.add_role_to_domain': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_role_to_domain',
                                    'sphinx.application.Sphinx.add_search_language': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_search_language',
                                    'sphinx.application.Sphinx.add_source_parser': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_source_parser',
                                    'sphinx.application.Sphinx.add_source_suffix': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_source_suffix',
                                    'sphinx.application.Sphinx.add_transform': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.add_transform',
                                    'sphinx.application.Sphinx.connect': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.connect',
                                    'sphinx.application.Sphinx.disconnect': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.disconnect',
                                    'sphinx.application.Sphinx.emit': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.emit',
                                    'sphinx.application.Sphinx.emit_firstresult': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.emit_firstresult',
                                    'sphinx.application.Sphinx.is_parallel_allowed': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.is_parallel_allowed',
                                    'sphinx.application.Sphinx.require_sphinx': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.require_sphinx',
                                    'sphinx.application.Sphinx.set_translator': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.set_translator',
                                    'sphinx.application.Sphinx.setup_extension': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.Sphinx.setup_extension',
                                    'sphinx.application.TemplateBridge': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.TemplateBridge',
                                    'sphinx.application.TemplateBridge.init': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.TemplateBridge.init',
                                    'sphinx.application.TemplateBridge.newest_template_mtime': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.TemplateBridge.newest_template_mtime',
                                    'sphinx.application.TemplateBridge.render': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.TemplateBridge.render',
                                    'sphinx.application.TemplateBridge.render_string': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.application.TemplateBridge.render_string'},
            'sphinx.builders': { 'sphinx.builders.Builder': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder',
                                 'sphinx.builders.Builder.build': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.build',
                                 'sphinx.builders.Builder.build_all': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.build_all',
                                 'sphinx.builders.Builder.build_specific': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.build_specific',
                                 'sphinx.builders.Builder.build_update': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.build_update',
                                 'sphinx.builders.Builder.finish': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.finish',
                                 'sphinx.builders.Builder.get_outdated_docs': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.get_outdated_docs',
                                 'sphinx.builders.Builder.get_relative_uri': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.get_relative_uri',
                                 'sphinx.builders.Builder.get_target_uri': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.get_target_uri',
                                 'sphinx.builders.Builder.init': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.init',
                                 'sphinx.builders.Builder.prepare_writing': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.prepare_writing',
                                 'sphinx.builders.Builder.write_doc': 'https://www.sphinx-doc.org/en/stable/extdev/builderapi.html#sphinx.builders.Builder.write_doc',
                                 'sphinx.builders.changes': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.changes',
                                 'sphinx.builders.dirhtml': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.dirhtml',
                                 'sphinx.builders.dummy': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.dummy',
                                 'sphinx.builders.epub3': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.epub3',
                                 'sphinx.builders.gettext': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.gettext',
                                 'sphinx.builders.html': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.html',
                                 'sphinx.builders.latex': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.latex',
                                 'sphinx.builders.linkcheck': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.linkcheck',
                                 'sphinx.builders.manpage': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.manpage',
                                 'sphinx.builders.singlehtml': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.singlehtml',
                                 'sphinx.builders.texinfo': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.texinfo',
                                 'sphinx.builders.text': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.text',
                                 'sphinx.builders.xml': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinx.builders.xml'},
            'sphinx.builders.changes': { 'sphinx.builders.changes.ChangesBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.changes.ChangesBuilder'},
            'sphinx.builders.dirhtml': { 'sphinx.builders.dirhtml.DirectoryHTMLBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.dirhtml.DirectoryHTMLBuilder'},
            'sphinx.builders.dummy': { 'sphinx.builders.dummy.DummyBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.dummy.DummyBuilder'},
            'sphinx.builders.epub3': { 'sphinx.builders.epub3.Epub3Builder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.epub3.Epub3Builder'},
            'sphinx.builders.gettext': { 'sphinx.builders.gettext.MessageCatalogBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.gettext.MessageCatalogBuilder'},
            'sphinx.builders.html': { 'sphinx.builders.html.StandaloneHTMLBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.html.StandaloneHTMLBuilder'},
            'sphinx.builders.latex': { 'sphinx.builders.latex.LaTeXBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.latex.LaTeXBuilder'},
            'sphinx.builders.linkcheck': { 'sphinx.builders.linkcheck.CheckExternalLinksBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.linkcheck.CheckExternalLinksBuilder'},
            'sphinx.builders.manpage': { 'sphinx.builders.manpage.ManualPageBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.manpage.ManualPageBuilder'},
            'sphinx.builders.singlehtml': { 'sphinx.builders.singlehtml.SingleFileHTMLBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.singlehtml.SingleFileHTMLBuilder'},
            'sphinx.builders.texinfo': { 'sphinx.builders.texinfo.TexinfoBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.texinfo.TexinfoBuilder'},
            'sphinx.builders.text': { 'sphinx.builders.text.TextBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.text.TextBuilder'},
            'sphinx.builders.xml': { 'sphinx.builders.xml.PseudoXMLBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.xml.PseudoXMLBuilder',
                                     'sphinx.builders.xml.XMLBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinx.builders.xml.XMLBuilder'},
            'sphinx.config': {'sphinx.config.Config': 'https://www.sphinx-doc.org/en/stable/extdev/appapi.html#sphinx.config.Config'},
            'sphinx.directives': { 'sphinx.directives.ObjectDescription': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription',
                                   'sphinx.directives.ObjectDescription._object_hierarchy_parts': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription._object_hierarchy_parts',
                                   'sphinx.directives.ObjectDescription._toc_entry_name': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription._toc_entry_name',
                                   'sphinx.directives.ObjectDescription.add_target_and_index': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription.add_target_and_index',
                                   'sphinx.directives.ObjectDescription.after_content': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription.after_content',
                                   'sphinx.directives.ObjectDescription.before_content': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription.before_content',
                                   'sphinx.directives.ObjectDescription.get_signatures': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription.get_signatures',
                                   'sphinx.directives.ObjectDescription.handle_signature': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription.handle_signature',
                                   'sphinx.directives.ObjectDescription.run': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription.run',
                                   'sphinx.directives.ObjectDescription.transform_content': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.directives.ObjectDescription.transform_content'},
            'sphinx.domains': { 'sphinx.domains.Domain': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain',
                                'sphinx.domains.Domain.add_object_type': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.add_object_type',
                                'sphinx.domains.Domain.check_consistency': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.check_consistency',
                                'sphinx.domains.Domain.clear_doc': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.clear_doc',
                                'sphinx.domains.Domain.directive': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.directive',
                                'sphinx.domains.Domain.get_enumerable_node_type': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.get_enumerable_node_type',
                                'sphinx.domains.Domain.get_full_qualified_name': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.get_full_qualified_name',
                                'sphinx.domains.Domain.get_objects': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.get_objects',
                                'sphinx.domains.Domain.get_type_name': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.get_type_name',
                                'sphinx.domains.Domain.merge_domaindata': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.merge_domaindata',
                                'sphinx.domains.Domain.process_doc': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.process_doc',
                                'sphinx.domains.Domain.process_field_xref': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.process_field_xref',
                                'sphinx.domains.Domain.resolve_any_xref': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.resolve_any_xref',
                                'sphinx.domains.Domain.resolve_xref': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.resolve_xref',
                                'sphinx.domains.Domain.role': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.role',
                                'sphinx.domains.Domain.setup': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Domain.setup',
                                'sphinx.domains.Index': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Index',
                                'sphinx.domains.Index.generate': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.Index.generate',
                                'sphinx.domains.ObjType': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.ObjType',
                                'sphinx.domains.python': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#module-sphinx.domains.python'},
            'sphinx.domains.python': { 'sphinx.domains.python.PythonDomain': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.python.PythonDomain',
                                       'sphinx.domains.python.PythonDomain.note_module': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.python.PythonDomain.note_module',
                                       'sphinx.domains.python.PythonDomain.note_object': 'https://www.sphinx-doc.org/en/stable/extdev/domainapi.html#sphinx.domains.python.PythonDomain.note_object'},
            'sphinx.environment': { 'sphinx.environment.BuildEnvironment': 'https://www.sphinx-doc.org/en/stable/extdev/envapi.html#sphinx.environment.BuildEnvironment',
                                    'sphinx.environment.BuildEnvironment.doc2path': 'https://www.sphinx-doc.org/en/stable/extdev/envapi.html#sphinx.environment.BuildEnvironment.doc2path',
                                    'sphinx.environment.BuildEnvironment.new_serialno': 'https://www.sphinx-doc.org/en/stable/extdev/envapi.html#sphinx.environment.BuildEnvironment.new_serialno',
                                    'sphinx.environment.BuildEnvironment.note_dependency': 'https://www.sphinx-doc.org/en/stable/extdev/envapi.html#sphinx.environment.BuildEnvironment.note_dependency',
                                    'sphinx.environment.BuildEnvironment.note_reread': 'https://www.sphinx-doc.org/en/stable/extdev/envapi.html#sphinx.environment.BuildEnvironment.note_reread',
                                    'sphinx.environment.BuildEnvironment.relfn2path': 'https://www.sphinx-doc.org/en/stable/extdev/envapi.html#sphinx.environment.BuildEnvironment.relfn2path',
                                    'sphinx.environment.collectors': 'https://www.sphinx-doc.org/en/stable/extdev/collectorapi.html#module-sphinx.environment.collectors'},
            'sphinx.environment.collectors': { 'sphinx.environment.collectors.EnvironmentCollector': 'https://www.sphinx-doc.org/en/stable/extdev/collectorapi.html#sphinx.environment.collectors.EnvironmentCollector',
                                               'sphinx.environment.collectors.EnvironmentCollector.clear_doc': 'https://www.sphinx-doc.org/en/stable/extdev/collectorapi.html#sphinx.environment.collectors.EnvironmentCollector.clear_doc',
                                               'sphinx.environment.collectors.EnvironmentCollector.get_outdated_docs': 'https://www.sphinx-doc.org/en/stable/extdev/collectorapi.html#sphinx.environment.collectors.EnvironmentCollector.get_outdated_docs',
                                               'sphinx.environment.collectors.EnvironmentCollector.get_updated_docs': 'https://www.sphinx-doc.org/en/stable/extdev/collectorapi.html#sphinx.environment.collectors.EnvironmentCollector.get_updated_docs',
                                               'sphinx.environment.collectors.EnvironmentCollector.merge_other': 'https://www.sphinx-doc.org/en/stable/extdev/collectorapi.html#sphinx.environment.collectors.EnvironmentCollector.merge_other',
                                               'sphinx.environment.collectors.EnvironmentCollector.process_doc': 'https://www.sphinx-doc.org/en/stable/extdev/collectorapi.html#sphinx.environment.collectors.EnvironmentCollector.process_doc'},
            'sphinx.events': { 'sphinx.events.EventManager': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.events.EventManager',
                               'sphinx.events.EventManager.add': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.events.EventManager.add',
                               'sphinx.events.EventManager.connect': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.events.EventManager.connect',
                               'sphinx.events.EventManager.disconnect': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.events.EventManager.disconnect',
                               'sphinx.events.EventManager.emit': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.events.EventManager.emit',
                               'sphinx.events.EventManager.emit_firstresult': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.events.EventManager.emit_firstresult'},
            'sphinx.ext': { 'sphinx.ext.autodoc': 'https://www.sphinx-doc.org/en/stable/usage/extensions/autodoc.html#module-sphinx.ext.autodoc',
                            'sphinx.ext.autosectionlabel': 'https://www.sphinx-doc.org/en/stable/usage/extensions/autosectionlabel.html#module-sphinx.ext.autosectionlabel',
                            'sphinx.ext.autosummary': 'https://www.sphinx-doc.org/en/stable/usage/extensions/autosummary.html#module-sphinx.ext.autosummary',
                            'sphinx.ext.coverage': 'https://www.sphinx-doc.org/en/stable/usage/extensions/coverage.html#module-sphinx.ext.coverage',
                            'sphinx.ext.doctest': 'https://www.sphinx-doc.org/en/stable/usage/extensions/doctest.html#module-sphinx.ext.doctest',
                            'sphinx.ext.duration': 'https://www.sphinx-doc.org/en/stable/usage/extensions/duration.html#module-sphinx.ext.duration',
                            'sphinx.ext.extlinks': 'https://www.sphinx-doc.org/en/stable/usage/extensions/extlinks.html#module-sphinx.ext.extlinks',
                            'sphinx.ext.githubpages': 'https://www.sphinx-doc.org/en/stable/usage/extensions/githubpages.html#module-sphinx.ext.githubpages',
                            'sphinx.ext.graphviz': 'https://www.sphinx-doc.org/en/stable/usage/extensions/graphviz.html#module-sphinx.ext.graphviz',
                            'sphinx.ext.ifconfig': 'https://www.sphinx-doc.org/en/stable/usage/extensions/ifconfig.html#module-sphinx.ext.ifconfig',
                            'sphinx.ext.imgconverter': 'https://www.sphinx-doc.org/en/stable/usage/extensions/imgconverter.html#module-sphinx.ext.imgconverter',
                            'sphinx.ext.imgmath': 'https://www.sphinx-doc.org/en/stable/usage/extensions/math.html#module-sphinx.ext.imgmath',
                            'sphinx.ext.inheritance_diagram': 'https://www.sphinx-doc.org/en/stable/usage/extensions/inheritance.html#module-sphinx.ext.inheritance_diagram',
                            'sphinx.ext.intersphinx': 'https://www.sphinx-doc.org/en/stable/usage/extensions/intersphinx.html#module-sphinx.ext.intersphinx',
                            'sphinx.ext.jsmath': 'https://www.sphinx-doc.org/en/stable/usage/extensions/math.html#module-sphinx.ext.jsmath',
                            'sphinx.ext.linkcode': 'https://www.sphinx-doc.org/en/stable/usage/extensions/linkcode.html#module-sphinx.ext.linkcode',
                            'sphinx.ext.mathbase': 'https://www.sphinx-doc.org/en/stable/usage/extensions/math.html#module-sphinx.ext.mathbase',
                            'sphinx.ext.mathjax': 'https://www.sphinx-doc.org/en/stable/usage/extensions/math.html#module-sphinx.ext.mathjax',
                            'sphinx.ext.napoleon': 'https://www.sphinx-doc.org/en/stable/usage/extensions/napoleon.html#module-sphinx.ext.napoleon',
                            'sphinx.ext.todo': 'https://www.sphinx-doc.org/en/stable/usage/extensions/todo.html#module-sphinx.ext.todo',
                            'sphinx.ext.viewcode': 'https://www.sphinx-doc.org/en/stable/usage/extensions/viewcode.html#module-sphinx.ext.viewcode'},
            'sphinx.ext.autodoc': { 'sphinx.ext.autodoc.between': 'https://www.sphinx-doc.org/en/stable/usage/extensions/autodoc.html#sphinx.ext.autodoc.between',
                                    'sphinx.ext.autodoc.cut_lines': 'https://www.sphinx-doc.org/en/stable/usage/extensions/autodoc.html#sphinx.ext.autodoc.cut_lines'},
            'sphinx.ext.coverage': { 'sphinx.ext.coverage.CoverageBuilder': 'https://www.sphinx-doc.org/en/stable/usage/extensions/coverage.html#sphinx.ext.coverage.CoverageBuilder'},
            'sphinx.locale': { 'sphinx.locale._': 'https://www.sphinx-doc.org/en/stable/extdev/i18n.html#sphinx.locale._',
                               'sphinx.locale.__': 'https://www.sphinx-doc.org/en/stable/extdev/i18n.html#sphinx.locale.__',
                               'sphinx.locale.get_translation': 'https://www.sphinx-doc.org/en/stable/extdev/i18n.html#sphinx.locale.get_translation',
                               'sphinx.locale.init': 'https://www.sphinx-doc.org/en/stable/extdev/i18n.html#sphinx.locale.init',
                               'sphinx.locale.init_console': 'https://www.sphinx-doc.org/en/stable/extdev/i18n.html#sphinx.locale.init_console'},
            'sphinx.parsers': { 'sphinx.parsers.Parser': 'https://www.sphinx-doc.org/en/stable/extdev/parserapi.html#sphinx.parsers.Parser',
                                'sphinx.parsers.Parser.set_application': 'https://www.sphinx-doc.org/en/stable/extdev/parserapi.html#sphinx.parsers.Parser.set_application'},
            'sphinx.project': { 'sphinx.project.Project': 'https://www.sphinx-doc.org/en/stable/extdev/projectapi.html#sphinx.project.Project',
                                'sphinx.project.Project.discover': 'https://www.sphinx-doc.org/en/stable/extdev/projectapi.html#sphinx.project.Project.discover',
                                'sphinx.project.Project.doc2path': 'https://www.sphinx-doc.org/en/stable/extdev/projectapi.html#sphinx.project.Project.doc2path',
                                'sphinx.project.Project.path2doc': 'https://www.sphinx-doc.org/en/stable/extdev/projectapi.html#sphinx.project.Project.path2doc',
                                'sphinx.project.Project.restore': 'https://www.sphinx-doc.org/en/stable/extdev/projectapi.html#sphinx.project.Project.restore'},
            'sphinx.transforms': { 'sphinx.transforms.SphinxTransform': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.transforms.SphinxTransform'},
            'sphinx.transforms.post_transforms': { 'sphinx.transforms.post_transforms.SphinxPostTransform': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.transforms.post_transforms.SphinxPostTransform',
                                                   'sphinx.transforms.post_transforms.SphinxPostTransform.apply': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.transforms.post_transforms.SphinxPostTransform.apply',
                                                   'sphinx.transforms.post_transforms.SphinxPostTransform.is_supported': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.transforms.post_transforms.SphinxPostTransform.is_supported',
                                                   'sphinx.transforms.post_transforms.SphinxPostTransform.run': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.transforms.post_transforms.SphinxPostTransform.run'},
            'sphinx.transforms.post_transforms.images': { 'sphinx.transforms.post_transforms.images.ImageConverter': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.transforms.post_transforms.images.ImageConverter',
                                                          'sphinx.transforms.post_transforms.images.ImageConverter.convert': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.transforms.post_transforms.images.ImageConverter.convert',
                                                          'sphinx.transforms.post_transforms.images.ImageConverter.is_available': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.transforms.post_transforms.images.ImageConverter.is_available'},
            'sphinx.util.docutils': { 'sphinx.util.docutils.ReferenceRole': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.util.docutils.ReferenceRole',
                                      'sphinx.util.docutils.SphinxDirective': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.util.docutils.SphinxDirective',
                                      'sphinx.util.docutils.SphinxDirective.get_location': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.util.docutils.SphinxDirective.get_location',
                                      'sphinx.util.docutils.SphinxDirective.get_source_info': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.util.docutils.SphinxDirective.get_source_info',
                                      'sphinx.util.docutils.SphinxDirective.set_source_info': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.util.docutils.SphinxDirective.set_source_info',
                                      'sphinx.util.docutils.SphinxRole': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.util.docutils.SphinxRole',
                                      'sphinx.util.docutils.SphinxRole.get_location': 'https://www.sphinx-doc.org/en/stable/extdev/utils.html#sphinx.util.docutils.SphinxRole.get_location'},
            'sphinx.util.logging': { 'sphinx.util.logging.SphinxLoggerAdapter': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.SphinxLoggerAdapter',
                                     'sphinx.util.logging.SphinxLoggerAdapter.critical': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.SphinxLoggerAdapter.critical',
                                     'sphinx.util.logging.SphinxLoggerAdapter.debug': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.SphinxLoggerAdapter.debug',
                                     'sphinx.util.logging.SphinxLoggerAdapter.error': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.SphinxLoggerAdapter.error',
                                     'sphinx.util.logging.SphinxLoggerAdapter.info': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.SphinxLoggerAdapter.info',
                                     'sphinx.util.logging.SphinxLoggerAdapter.log': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.SphinxLoggerAdapter.log',
                                     'sphinx.util.logging.SphinxLoggerAdapter.verbose': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.SphinxLoggerAdapter.verbose',
                                     'sphinx.util.logging.SphinxLoggerAdapter.warning': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.SphinxLoggerAdapter.warning',
                                     'sphinx.util.logging.getLogger': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.getLogger',
                                     'sphinx.util.logging.pending_logging': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.pending_logging',
                                     'sphinx.util.logging.pending_warnings': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.pending_warnings',
                                     'sphinx.util.logging.prefixed_warnings': 'https://www.sphinx-doc.org/en/stable/extdev/logging.html#sphinx.util.logging.prefixed_warnings'},
            'sphinxcontrib': { 'sphinxcontrib.applehelp': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinxcontrib.applehelp',
                               'sphinxcontrib.devhelp': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinxcontrib.devhelp',
                               'sphinxcontrib.htmlhelp': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinxcontrib.htmlhelp',
                               'sphinxcontrib.qthelp': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#module-sphinxcontrib.qthelp'},
            'sphinxcontrib.applehelp': { 'sphinxcontrib.applehelp.AppleHelpBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinxcontrib.applehelp.AppleHelpBuilder'},
            'sphinxcontrib.devhelp': { 'sphinxcontrib.devhelp.DevhelpBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinxcontrib.devhelp.DevhelpBuilder'},
            'sphinxcontrib.htmlhelp': { 'sphinxcontrib.htmlhelp.HTMLHelpBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinxcontrib.htmlhelp.HTMLHelpBuilder'},
            'sphinxcontrib.qthelp': { 'sphinxcontrib.qthelp.QtHelpBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinxcontrib.qthelp.QtHelpBuilder'},
            'sphinxcontrib.serializinghtml': { 'sphinxcontrib.serializinghtml.JSONHTMLBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinxcontrib.serializinghtml.JSONHTMLBuilder',
                                               'sphinxcontrib.serializinghtml.PickleHTMLBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinxcontrib.serializinghtml.PickleHTMLBuilder',
                                               'sphinxcontrib.serializinghtml.SerializingHTMLBuilder': 'https://www.sphinx-doc.org/en/stable/usage/builders/index.html#sphinxcontrib.serializinghtml.SerializingHTMLBuilder'},
            'sphinxcontrib.websupport': { 'sphinxcontrib.websupport.WebSupport': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/api.html#sphinxcontrib.websupport.WebSupport',
                                          'sphinxcontrib.websupport.WebSupport.add_comment': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/api.html#sphinxcontrib.websupport.WebSupport.add_comment',
                                          'sphinxcontrib.websupport.WebSupport.build': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/api.html#sphinxcontrib.websupport.WebSupport.build',
                                          'sphinxcontrib.websupport.WebSupport.get_data': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/api.html#sphinxcontrib.websupport.WebSupport.get_data',
                                          'sphinxcontrib.websupport.WebSupport.get_document': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/api.html#sphinxcontrib.websupport.WebSupport.get_document',
                                          'sphinxcontrib.websupport.WebSupport.get_search_results': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/api.html#sphinxcontrib.websupport.WebSupport.get_search_results',
                                          'sphinxcontrib.websupport.WebSupport.process_vote': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/api.html#sphinxcontrib.websupport.WebSupport.process_vote'},
            'sphinxcontrib.websupport.search': { 'sphinxcontrib.websupport.search.BaseSearch': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/searchadapters.html#sphinxcontrib.websupport.search.BaseSearch',
                                                 'sphinxcontrib.websupport.search.BaseSearch.add_document': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/searchadapters.html#sphinxcontrib.websupport.search.BaseSearch.add_document',
                                                 'sphinxcontrib.websupport.search.BaseSearch.extract_context': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/searchadapters.html#sphinxcontrib.websupport.search.BaseSearch.extract_context',
                                                 'sphinxcontrib.websupport.search.BaseSearch.feed': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/searchadapters.html#sphinxcontrib.websupport.search.BaseSearch.feed',
                                                 'sphinxcontrib.websupport.search.BaseSearch.finish_indexing': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/searchadapters.html#sphinxcontrib.websupport.search.BaseSearch.finish_indexing',
                                                 'sphinxcontrib.websupport.search.BaseSearch.handle_query': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/searchadapters.html#sphinxcontrib.websupport.search.BaseSearch.handle_query',
                                                 'sphinxcontrib.websupport.search.BaseSearch.init_indexing': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/searchadapters.html#sphinxcontrib.websupport.search.BaseSearch.init_indexing',
                                                 'sphinxcontrib.websupport.search.BaseSearch.query': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/searchadapters.html#sphinxcontrib.websupport.search.BaseSearch.query'},
            'sphinxcontrib.websupport.storage': { 'sphinxcontrib.websupport.storage.StorageBackend': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend',
                                                  'sphinxcontrib.websupport.storage.StorageBackend.accept_comment': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend.accept_comment',
                                                  'sphinxcontrib.websupport.storage.StorageBackend.add_comment': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend.add_comment',
                                                  'sphinxcontrib.websupport.storage.StorageBackend.add_node': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend.add_node',
                                                  'sphinxcontrib.websupport.storage.StorageBackend.delete_comment': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend.delete_comment',
                                                  'sphinxcontrib.websupport.storage.StorageBackend.get_data': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend.get_data',
                                                  'sphinxcontrib.websupport.storage.StorageBackend.post_build': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend.post_build',
                                                  'sphinxcontrib.websupport.storage.StorageBackend.pre_build': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend.pre_build',
                                                  'sphinxcontrib.websupport.storage.StorageBackend.process_vote': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend.process_vote',
                                                  'sphinxcontrib.websupport.storage.StorageBackend.update_username': 'https://www.sphinx-doc.org/en/stable/usage/advanced/websupport/storagebackends.html#sphinxcontrib.websupport.storage.StorageBackend.update_username'}}}
